==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkStringToNumeric.java <==
// java wrapper for vtkStringToNumeric object
//

package vtk;
import vtk.*;

public class vtkStringToNumeric extends vtkDataObjectAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetForceDouble_2(boolean id0);
  public void SetForceDouble(boolean id0)
    { SetForceDouble_2(id0); }

  private native boolean GetForceDouble_3();
  public boolean GetForceDouble()
    { return GetForceDouble_3(); }

  private native void ForceDoubleOn_4();
  public void ForceDoubleOn()
    { ForceDoubleOn_4(); }

  private native void ForceDoubleOff_5();
  public void ForceDoubleOff()
    { ForceDoubleOff_5(); }

  private native void SetDefaultIntegerValue_6(int id0);
  public void SetDefaultIntegerValue(int id0)
    { SetDefaultIntegerValue_6(id0); }

  private native int GetDefaultIntegerValue_7();
  public int GetDefaultIntegerValue()
    { return GetDefaultIntegerValue_7(); }

  private native void SetDefaultDoubleValue_8(double id0);
  public void SetDefaultDoubleValue(double id0)
    { SetDefaultDoubleValue_8(id0); }

  private native double GetDefaultDoubleValue_9();
  public double GetDefaultDoubleValue()
    { return GetDefaultDoubleValue_9(); }

  private native void SetTrimWhitespacePriorToNumericConversion_10(boolean id0);
  public void SetTrimWhitespacePriorToNumericConversion(boolean id0)
    { SetTrimWhitespacePriorToNumericConversion_10(id0); }

  private native boolean GetTrimWhitespacePriorToNumericConversion_11();
  public boolean GetTrimWhitespacePriorToNumericConversion()
    { return GetTrimWhitespacePriorToNumericConversion_11(); }

  private native void TrimWhitespacePriorToNumericConversionOn_12();
  public void TrimWhitespacePriorToNumericConversionOn()
    { TrimWhitespacePriorToNumericConversionOn_12(); }

  private native void TrimWhitespacePriorToNumericConversionOff_13();
  public void TrimWhitespacePriorToNumericConversionOff()
    { TrimWhitespacePriorToNumericConversionOff_13(); }

  private native void SetConvertFieldData_14(boolean id0);
  public void SetConvertFieldData(boolean id0)
    { SetConvertFieldData_14(id0); }

  private native boolean GetConvertFieldData_15();
  public boolean GetConvertFieldData()
    { return GetConvertFieldData_15(); }

  private native void ConvertFieldDataOn_16();
  public void ConvertFieldDataOn()
    { ConvertFieldDataOn_16(); }

  private native void ConvertFieldDataOff_17();
  public void ConvertFieldDataOff()
    { ConvertFieldDataOff_17(); }

  private native void SetConvertPointData_18(boolean id0);
  public void SetConvertPointData(boolean id0)
    { SetConvertPointData_18(id0); }

  private native boolean GetConvertPointData_19();
  public boolean GetConvertPointData()
    { return GetConvertPointData_19(); }

  private native void ConvertPointDataOn_20();
  public void ConvertPointDataOn()
    { ConvertPointDataOn_20(); }

  private native void ConvertPointDataOff_21();
  public void ConvertPointDataOff()
    { ConvertPointDataOff_21(); }

  private native void SetConvertCellData_22(boolean id0);
  public void SetConvertCellData(boolean id0)
    { SetConvertCellData_22(id0); }

  private native boolean GetConvertCellData_23();
  public boolean GetConvertCellData()
    { return GetConvertCellData_23(); }

  private native void ConvertCellDataOn_24();
  public void ConvertCellDataOn()
    { ConvertCellDataOn_24(); }

  private native void ConvertCellDataOff_25();
  public void ConvertCellDataOff()
    { ConvertCellDataOff_25(); }

  private native void SetConvertVertexData_26(boolean id0);
  public void SetConvertVertexData(boolean id0)
    { SetConvertVertexData_26(id0); }

  private native boolean GetConvertVertexData_27();
  public boolean GetConvertVertexData()
    { return GetConvertVertexData_27(); }

  private native void ConvertVertexDataOn_28();
  public void ConvertVertexDataOn()
    { ConvertVertexDataOn_28(); }

  private native void ConvertVertexDataOff_29();
  public void ConvertVertexDataOff()
    { ConvertVertexDataOff_29(); }

  private native void SetConvertEdgeData_30(boolean id0);
  public void SetConvertEdgeData(boolean id0)
    { SetConvertEdgeData_30(id0); }

  private native boolean GetConvertEdgeData_31();
  public boolean GetConvertEdgeData()
    { return GetConvertEdgeData_31(); }

  private native void ConvertEdgeDataOn_32();
  public void ConvertEdgeDataOn()
    { ConvertEdgeDataOn_32(); }

  private native void ConvertEdgeDataOff_33();
  public void ConvertEdgeDataOff()
    { ConvertEdgeDataOff_33(); }

  private native void SetConvertRowData_34(boolean id0);
  public void SetConvertRowData(boolean id0)
    { SetConvertRowData_34(id0); }

  private native boolean GetConvertRowData_35();
  public boolean GetConvertRowData()
    { return GetConvertRowData_35(); }

  private native void ConvertRowDataOn_36();
  public void ConvertRowDataOn()
    { ConvertRowDataOn_36(); }

  private native void ConvertRowDataOff_37();
  public void ConvertRowDataOff()
    { ConvertRowDataOff_37(); }

  public vtkStringToNumeric() { super(); }

  public vtkStringToNumeric(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-13-aarch64.pkg.tar.xz: vtk/vtkStringToNumeric.java <==
// java wrapper for vtkStringToNumeric object
//

package vtk;
import vtk.*;

public class vtkStringToNumeric extends vtkDataObjectAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetForceDouble_2(boolean id0);
  public void SetForceDouble(boolean id0)
    { SetForceDouble_2(id0); }

  private native boolean GetForceDouble_3();
  public boolean GetForceDouble()
    { return GetForceDouble_3(); }

  private native void ForceDoubleOn_4();
  public void ForceDoubleOn()
    { ForceDoubleOn_4(); }

  private native void ForceDoubleOff_5();
  public void ForceDoubleOff()
    { ForceDoubleOff_5(); }

  private native void SetDefaultIntegerValue_6(int id0);
  public void SetDefaultIntegerValue(int id0)
    { SetDefaultIntegerValue_6(id0); }

  private native int GetDefaultIntegerValue_7();
  public int GetDefaultIntegerValue()
    { return GetDefaultIntegerValue_7(); }

  private native void SetDefaultDoubleValue_8(double id0);
  public void SetDefaultDoubleValue(double id0)
    { SetDefaultDoubleValue_8(id0); }

  private native double GetDefaultDoubleValue_9();
  public double GetDefaultDoubleValue()
    { return GetDefaultDoubleValue_9(); }

  private native void SetTrimWhitespacePriorToNumericConversion_10(boolean id0);
  public void SetTrimWhitespacePriorToNumericConversion(boolean id0)
    { SetTrimWhitespacePriorToNumericConversion_10(id0); }

  private native boolean GetTrimWhitespacePriorToNumericConversion_11();
  public boolean GetTrimWhitespacePriorToNumericConversion()
    { return GetTrimWhitespacePriorToNumericConversion_11(); }

  private native void TrimWhitespacePriorToNumericConversionOn_12();
  public void TrimWhitespacePriorToNumericConversionOn()
    { TrimWhitespacePriorToNumericConversionOn_12(); }

  private native void TrimWhitespacePriorToNumericConversionOff_13();
  public void TrimWhitespacePriorToNumericConversionOff()
    { TrimWhitespacePriorToNumericConversionOff_13(); }

  private native void SetConvertFieldData_14(boolean id0);
  public void SetConvertFieldData(boolean id0)
    { SetConvertFieldData_14(id0); }

  private native boolean GetConvertFieldData_15();
  public boolean GetConvertFieldData()
    { return GetConvertFieldData_15(); }

  private native void ConvertFieldDataOn_16();
  public void ConvertFieldDataOn()
    { ConvertFieldDataOn_16(); }

  private native void ConvertFieldDataOff_17();
  public void ConvertFieldDataOff()
    { ConvertFieldDataOff_17(); }

  private native void SetConvertPointData_18(boolean id0);
  public void SetConvertPointData(boolean id0)
    { SetConvertPointData_18(id0); }

  private native boolean GetConvertPointData_19();
  public boolean GetConvertPointData()
    { return GetConvertPointData_19(); }

  private native void ConvertPointDataOn_20();
  public void ConvertPointDataOn()
    { ConvertPointDataOn_20(); }

  private native void ConvertPointDataOff_21();
  public void ConvertPointDataOff()
    { ConvertPointDataOff_21(); }

  private native void SetConvertCellData_22(boolean id0);
  public void SetConvertCellData(boolean id0)
    { SetConvertCellData_22(id0); }

  private native boolean GetConvertCellData_23();
  public boolean GetConvertCellData()
    { return GetConvertCellData_23(); }

  private native void ConvertCellDataOn_24();
  public void ConvertCellDataOn()
    { ConvertCellDataOn_24(); }

  private native void ConvertCellDataOff_25();
  public void ConvertCellDataOff()
    { ConvertCellDataOff_25(); }

  private native void SetConvertVertexData_26(boolean id0);
  public void SetConvertVertexData(boolean id0)
    { SetConvertVertexData_26(id0); }

  private native boolean GetConvertVertexData_27();
  public boolean GetConvertVertexData()
    { return GetConvertVertexData_27(); }

  private native void ConvertVertexDataOn_28();
  public void ConvertVertexDataOn()
    { ConvertVertexDataOn_28(); }

  private native void ConvertVertexDataOff_29();
  public void ConvertVertexDataOff()
    { ConvertVertexDataOff_29(); }

  private native void SetConvertEdgeData_30(boolean id0);
  public void SetConvertEdgeData(boolean id0)
    { SetConvertEdgeData_30(id0); }

  private native boolean GetConvertEdgeData_31();
  public boolean GetConvertEdgeData()
    { return GetConvertEdgeData_31(); }

  private native void ConvertEdgeDataOn_32();
  public void ConvertEdgeDataOn()
    { ConvertEdgeDataOn_32(); }

  private native void ConvertEdgeDataOff_33();
  public void ConvertEdgeDataOff()
    { ConvertEdgeDataOff_33(); }

  private native void SetConvertRowData_34(boolean id0);
  public void SetConvertRowData(boolean id0)
    { SetConvertRowData_34(id0); }

  private native boolean GetConvertRowData_35();
  public boolean GetConvertRowData()
    { return GetConvertRowData_35(); }

  private native void ConvertRowDataOn_36();
  public void ConvertRowDataOn()
    { ConvertRowDataOn_36(); }

  private native void ConvertRowDataOff_37();
  public void ConvertRowDataOff()
    { ConvertRowDataOff_37(); }

  public vtkStringToNumeric() { super(); }

  public vtkStringToNumeric(long id) { super(id); }
  public native long   VTKInit();

}
